@@ -62,19 +62,22 @@
 #include "DapObj.h"
 #endif
 
+#if 0
 #ifndef KEYWORDS_H_
 #include "Keywords2.h"
 #endif
+#endif
 
 #ifndef XMLWRITER_H_
 #include "XMLWriter.h"
 #endif
 
-using std::cout;
-
 namespace libdap
 {
 
+bool has_dap2_attributes(BaseType *btp);
+bool has_dap2_attributes(AttrTable &a);
+
 /** The DAP2 Data Descriptor Object (DDS) is a data structure used by
     the DAP2 software to describe datasets and subsets of those
     datasets.  The DDS may be thought of as the declarations for the
@@ -201,7 +204,9 @@ private:
     int d_timeout;              // alarm time in seconds. If greater than
                                 // zero, raise the alarm signal if more than
                                 // d_timeout seconds are spent reading data.
+#if 0
     Keywords d_keywords;	    // Holds keywords parsed from the CE
+#endif
 
     long d_max_response_size;   // In bytes...
 
@@ -273,7 +278,9 @@ public:
     /// @deprecated
     void set_dap_version(double d);
 
-    Keywords &get_keywords() { return d_keywords; }
+#if 0
+    Keywords &get_keywords() {return d_keywords;}
+#endif
 
     /// Get the URL that will return this DDS/DDX/DataThing
     string get_request_xml_base() const { return d_request_xml_base; }
@@ -349,7 +356,7 @@ public:
     void timeout_off();
     void set_timeout(int t);
     int get_timeout();
-    //@}
+    ///@}
 
     // These parse the DAP2 curly-brace document and make a C++ object.
     void parse(string fname);
@@ -373,6 +380,8 @@ public:
     void print_dmr(ostream &out, bool constrained);
 
     void print_das(ostream &out);
+    DAS *get_das();
+    void get_das(DAS *das);
 
     void mark_all(bool state);
     bool mark(const string &name, bool state);
