@@ -88,7 +88,7 @@ static const char *http_client_errors[CLIENT_ERR_MAX - CLIENT_ERR_MIN +1] =
         "Payment Required.",
         "Forbidden: Contact the server administrator.",
         "Not Found: The data source or server could not be found.\n\
-        Often this means that the OPeNDAP server is missing or needs attention;\n\
+        Often this means that the OPeNDAP server is missing or needs attention.\n\
         Please contact the server administrator.",
         "Method Not Allowed.",
         "Not Acceptable.",
