@@ -9,7 +9,7 @@
 using namespace std;
 
 string
-readTestBaseline(const string &fn)
+read_test_baseline(const string &fn)
 {
     int length;
 
